blacken-docs-jb
===============

Extension of [blancken-docs](https://github.com/asottile/blacken-docs) which also supports the [executable code blocks](https://jupyterbook.org/en/stable/reference/cheatsheet.html#executable-code) from [JupyterBook](https://jupyterbook.org) e.g

````
```{code-cell} python
x = 1 + 2
```
````


## install

```bash
pip install blacken-docs-jb
```
